/*
 * DiaSCE
 * Copyright (C) 2001  Ander Lozano Prez
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Ander Lozano Prez
 * ander1@wanadoo.es
 */

#include "main.h"

//*******************************************************************

enum e_pixmaps {PROYECTO=0,CABECERAS,FUENTES,OTROS,ARCHIVO,CLASES,FUNCIONES,UNIONES,ESTRUCURAS,BARIABLES,ENUMERACIONES,TIPOS,MIEMBRO,TOTAL_PIXMAPS};

typedef GdkPixmap* GdkPixmapPtr;
typedef GdkPixbuf* GdkPixbufPtr;

//*******************************************************************

GdkPixbufPtr pixbufs[TOTAL_PIXMAPS];
GdkPixbuf *pix_marcador;

//*******************************************************************

void pix_inicializar(void);
